# Lighter
[![build](https://github.com/project-lighter/lighter/actions/workflows/build.yml/badge.svg?branch=main)](https://github.com/project-lighter/lighter/actions/workflows/build.yml) ![Coverage](./assets/images/coverage.svg)


## Setup

Run the following commands to develop with the repository and add the package in develop mode to your environment

````
make setup
make install 
````

To setup the pre-commit hook to format code before commit,
````
make pre-commit-install
````
